'use strict';

var _tokenize = require('../tokenize');

var _tokenize2 = _interopRequireDefault(_tokenize);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ruleMap = {
  identifier: /^[a-z-]+$/i,
  number: /^\d+$/,
  whitespace: /^\s+$/,
  comma: /^,+$/
};

describe('Tokenizing strings', function () {
  it('should return an array of tokens', function () {
    expect((0, _tokenize2.default)('test,  12 foobar13', ruleMap)).toEqual([{
      type: 'identifier',
      value: 'test',
      start: 0,
      end: 4
    }, {
      type: 'comma',
      value: ',',
      start: 4,
      end: 5
    }, {
      type: 'whitespace',
      value: '  ',
      start: 5,
      end: 7
    }, {
      type: 'number',
      value: '12',
      start: 7,
      end: 9
    }, {
      type: 'whitespace',
      value: ' ',
      start: 9,
      end: 10
    }, {
      type: 'identifier',
      value: 'foobar',
      start: 10,
      end: 16
    }, {
      type: 'number',
      value: '13',
      start: 16,
      end: 18
    }]);
  });

  it('should use a defaultTokenType', function () {
    expect((0, _tokenize2.default)('test $$', ruleMap, 'unknown')).toEqual([{ type: 'identifier', value: 'test', start: 0, end: 4 }, { type: 'whitespace', value: ' ', start: 4, end: 5 }, {
      type: 'unknown',
      value: '$',
      start: 5,
      end: 6
    }, {
      type: 'unknown',
      value: '$',
      start: 6,
      end: 7
    }]);
  });
});