'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = tokenize;

var _loopUntilConditionIsFulfilled = require('./loopUntilConditionIsFulfilled');

var _loopUntilConditionIsFulfilled2 = _interopRequireDefault(_loopUntilConditionIsFulfilled);

var _getFirstMatchingRule = require('./getFirstMatchingRule');

var _getFirstMatchingRule2 = _interopRequireDefault(_getFirstMatchingRule);

var _isEmpty = require('./isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function tokenize(input, ruleMap, defaultTokenType) {
  var tokens = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  var startIndex = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0;

  // stop at empty strings
  if ((0, _isEmpty2.default)(input) || input === 'undefined') {
    return tokens;
  }

  function isNotMatchingAnyRule(currentIndex) {
    return !(0, _getFirstMatchingRule2.default)(input.substring(0, currentIndex + 1), ruleMap);
  }

  var ruleEndIndex = (0, _loopUntilConditionIsFulfilled2.default)(input.length, isNotMatchingAnyRule

  // if no rule matched the first char
  // we have encountered invalid syntax
  // and thus can throw a syntax error
  );if (ruleEndIndex === 0) {
    if (defaultTokenType) {
      var _nextStartIndex = startIndex + 1;

      tokens.push({
        type: defaultTokenType,
        value: input.substring(0, 1),
        start: startIndex,
        end: _nextStartIndex
      });

      return tokenize(input.substring(1), ruleMap, defaultTokenType, tokens, _nextStartIndex);
    }

    throw new SyntaxError(input.substr(0, 15) + '... (Invalid Token:' + startIndex + ')\n             ^ does not match any rules.');
  }

  var matchedValue = input.substring(0, ruleEndIndex);
  var matchedTokenType = (0, _getFirstMatchingRule2.default)(matchedValue, ruleMap);

  var nextStartIndex = startIndex + ruleEndIndex;

  tokens.push({
    type: matchedTokenType,
    value: matchedValue,
    start: startIndex,
    end: nextStartIndex
  });

  return tokenize(input.substring(ruleEndIndex), ruleMap, defaultTokenType, tokens, nextStartIndex);
}